ClassificationEvaluator
=======================

.. currentmodule:: pykeen.evaluation

.. autoclass:: ClassificationEvaluator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ClassificationEvaluator.finalize
      ~ClassificationEvaluator.process_scores_

   .. rubric:: Methods Documentation

   .. automethod:: finalize
   .. automethod:: process_scores_
